
% HowTo start run_ffnn.m correctly ?
%
% run_ffnn.m sets parameters and starts training function
% Gabor feature set is automatically optimized by using the FFNN
% (Feature-Finding neural network), a linear NN combined with an
% optimization rule ('substitution rule' after Gramss 1992) in combination
% with AdaBoost Algorithm (Freund & Schapire, 1996)
%
% trialname: string defining trial and parameters (define before first use!!!):
% '[zifkom|TIdigits]_[noisy|clean]_ComplexGabor_[s_only|t_only|sandt_only|a_and_t_and_ST]_fdim23_[abs, real, imag]_[\d]Feat_[\d]Iter_[\d]BoostIt__[\d]Files_[\d]FmodTmin_[\d]FmodTmax'
% trainingflag: 1 indicates feature set optimization
% testflag: 1 indicates testing on unknown speech material
% testlist (optional): test conditions
%
% BoostIt: Number of Iterations for Boosting (1: ordinary FFNN)
% Feat: Number of Feature for the final set (Feat/BoostIt per BoostIteration subset)
% FmodTmin/max: denoting the (restricted) range of temporal modulation center freq in Hz 
%
% zifkom / TIdigits         which corpus
% noisy/clean:              which training corpus (clean or with added noise)
% Gabor                     use Gabor functions
% s_only:                   purely spectral gabor functions
% t_only:                   purely temporal gabor functions
% sandt_only                purely spectral gabor functions and purely temporal gabor functions
% s_and_t_and_ST            all Gabor functions including Spectro-temporal
% abs,real,imag:            type of Gabor refinement used
% 80Feat:                   80 Features in set
% 1000Iter:                    1000 Iterations
%
% Ex.: run_ffnn('zifkom_noisy_ComplexGabor_s_and_t_and_ST_fdim23_abs_3BoostIt_30Feat_40Iter',1,1,{'clean' 'noisy'})
% Ex.: run_ffnn('TIdigits_noisy_ComplexGabor_s_and_t_and_ST_fdim23_abs_3BoostIt_80Feat_200Iter',1,1,{'clean' 'noisy'})
%
% Ex.: run_ffnn('TIMIT_ICSI56_noisy_ComplexGabor_s_and_t_and_ST_fdim23_abs_20Feat_200Iter_100Files',1,0,{})
% Ex.: run_ffnn('TIMIT_Voicing3_clean_ComplexGabor_ST_only_fdim23_abs_10Feat_300Iter_200Files_1',1,0,{})
% Ex.: run_ffnn('TIMIT_Manner6_clean_ComplexGabor_ST_only_fdim23_abs_real_imag_30Feat_300I_200Files_1',1,0,{})
% Ex.: run_ffnn('TIMIT_Place9_clean_ComplexGabor_ST_only_fdim23_abs_30Feat_300Iter_200Files_1',1,0,{})
% Ex.: run_ffnn('TIMIT_BroadDupont10_clean_ComplexGabor_ST_only_fdim23_abs_30Feat_300Iter_200Files',1,0,{})
% Ex.: run_ffnn('TIMIT_BroadPlaceDupont9_clean_ComplexGabor_ST_only_fdim23_abs_30Feat_300Iter_200Files',1,0,{})
%
% Ex.: run_ffnn('TIMIT_Diphone_AFManner-iy_clean_ComplexGabor_ST_only_fdim23_abs_10Feat_10Iter_100Files',1,0,{})
% Ex.: run_ffnn('TIMIT_Diphone_AFManner-highallinone_clean_ComplexGabor_ST_only_fdim23_abs_10Feat_10Iter_100Files',1,0,{})
% Ex.: run_ffnn('TIMIT_Diphone_AFManner-all_clean_ComplexGabor_ST_only_fdim23_abs_10Feat_10Iter_100Files',1,0,{})
% Ex.: run_ffnn('TIMIT_Diphone_AFPlace-highvowels-VC_clean_ComplexGabor_ST_only_fdim23_abs_10Feat_10Iter_100Files',1,0,{})
% Ex.: run_ffnn('TIMIT_Diphone_AFPlace-allvowels_noisy-VC_ComplexGabor_ST_only_fdim23_abs_10Feat_10Iter_100Files',1,0,{})
% Ex.: run_ffnn('TIMIT_Diphone_AFPlace-highvowels_clean_ComplexGabor_ST_only_fdim23_abs_10Feat_10Iter_100Files',1,0,{})
% Ex.: run_ffnn('TIMIT_Diphone_AFPlace-allvowels_noisy_ComplexGabor_ST_only_fdim23_abs_10Feat_10Iter_100Files',1,0,{})
% Ex.: run_ffnn('TIMIT_Diphone_AFPlace-iy_noisy_ComplexGabor_ST_only_fdim23_abs_10Feat_10Iter_100Files',1,0,{})
% Ex.: run_ffnn('TIMIT_Diphone_AFPlace-ae_noisy_ComplexGabor_ST_only_fdim23_abs_10Feat_10Iter_100Files',1,0,{})
%
% Ex.: run_ffnn('TIMIT_Diphone_phones-diphthongs6_clean_ComplexGabor_ST_only_fdim23_abs_30Feat_300Iter_300Files_1',1,0,{})
% Ex.: run_ffnn('TIMIT_Diphone_phones-vowels8_clean_ComplexGabor_ST_only_fdim23_abs_40Feat_300Iter_300Files_1',1,0,{})
% Ex.: run_ffnn('TIMIT_Diphone_phones-stops14_clean_ComplexGabor_ST_only_fdim23_abs_50Feat_300Iter_300Files_1',1,0,{})
% Ex.: run_ffnn('TIMIT_Diphone_phones-nasal5_clean_ComplexGabor_ST_only_fdim23_abs_20Feat_300Iter_300Files_1',1,0,{})
% Ex.: run_ffnn('TIMIT_Diphone_phones-fricative10_clean_ComplexGabor_ST_only_fdim23_abs_40Feat_300Iter_300Files_1',1,0,{})

%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for academic purposes is generally
%%   granted.
%%
%%   Permission to modify the software is granted, but not the right to
%%   distribute the modified code.
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%-----------------------------------------------------------------------------
