function [sPrimary] = load_TIMIT_with_label(indir,condition,num,display_flag)

% function [sPrimary]=load_TIMIT_with_label(indir,condition,num,display_flag)
% 
% Example: [sPrimary]=load_TIMIT_with_label('/scratch/michaelk/TIMIT/noisy/melspec','noisy',1,1)
% Example: [sPrimary]=load_TIMIT_with_label('/scratch/michaelk/TIMIT/clean/melspec','clean',1,1)
%
% reads primary features from HTK format files and attaches the correct
% frame labels to it. information about using noisy/clean TIMIT directly
% implicates the labelfile, listfile and the subdirectory of the data.  
%
% IN:
% indir : string containing root feature directory
% condition : 'clean' or 'noisy' (identical to subdir)
% num : position of file in listfile, starting with 1
% display_flag : if TRUE feature vector sequence is plotted
%
% OUT:
% sPrimary: structure containing
%   - mIR : input feature matrix
%   - vLabel : label vector
%
% Michael Kleinschmidt, ICSI, Nov 2001

if strcmp(condition,'clean')
  listfile = './labels/TIMIT_clean_filelist.mat';
elseif strcmp(condition,'noisy')
  listfile = './labels/TIMIT_noisy_filelist.mat';
end
 
eval(['load ' listfile ' liste']);

infile = [indir '/' liste(num).name];
[sPrimary.mIR, sHeader] = load_htk_with_header(infile, display_flag);
eval(['load labels/' num2str(num) '.mat labels' ])

sPrimary.vLabels=labels';

% Check range of Labels
if ((max(sPrimary.vLabels)>55)|(min(sPrimary.vLabels)<0))
  fprintf('max=%i  min=%i',max(labels),min(labels))
end

% Check length of vLabels
if (length(sPrimary.vLabels)~=size(sPrimary.mIR,2))
  fprintf('lab: %i\tfeat: %i\n',length(sPrimary.vLabels),size(sPrimary.mIR,2))
end

%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for academic purposes is generally
%%   granted.
%%
%%   Permission to modify the software is granted, but not the right to
%%   distribute the modified code.
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%-----------------------------------------------------------------------------
