function [W, Psi] = trainer(X, Y, Dvec) 
% training of weight matrix using the pseudo inverse matrix
%
% Syntax: [net, pseudo] = trainer(features, manyIR.label, diag(Param.Dvec))
%
%
% Input: 
% -- W is the (M*N) weight matrix if the neural net 
%
% -- Y is the (M*P) target matrix
%
% -- X is a matrix containing secondary feature vectors
%     where X(number of feature, number of ST representation) corresponds to features
%	
% -- D is a diagonal P*P matrix, that contains boosting weights 
%     for each example
%
% -- Dvec is the diagonal of D with length P
%	
% Output:
% -- W ist the weight matrix of the classifying neural net with
%     Y  =   W  * X 
% (M*P)  = (M*N) * (N*P)
% -- Psi is the pseudo inverse of X(N*P, features*patterns)
%
% M = number of classes
% N = number of features
% P = number of patterns% 
%
% Michael Kleinschmidt, AG MEDI, Uni Oldenburg   19.6.99

% how many features ?
temp = size(X);
N = temp(1);

% how many patterns ?
P = temp(2);

% CHANGE
if (Param.UseBoosting == 0)
% if nargin==2 % no boosting, old pseudoinverse method
    
    if (P >= N) 
        Psi = inv(X * X');
        W = Y * X' * Psi;
    else
        Psi = inv(X' * X);
        W = Y * Psi * X';
    end
    
elseif nargin == 3 % use P for boosting
    
    % CHANGE
    error('At this point Boosing was used');
    % generate matrix from Dvec
    D=diag(Dvec);
    
    % the dependency between error and D should be linearly
    D=sqrt(D);
    
    if (P >= N) 
        Psi = inv(X*D*D*X');
        W = Y * D*D * X' * Psi;
    else 
        Psi = inv(D * X' * X * D);
        W = Y * D*D * Psi * X';
    end
    
end

% Tino Gramss' dissertation, page 31, equation 14

return

%%-----------------------------------------------------------------------------
%%
%%   Copyright (C) 2000-2004   
%%   Medizinische Physik,
%%   Universitaet Oldenburg, Germany
%%   http://www.physik.uni-oldenburg.de/docs/medi
%%
%%   Permission to use, copy, and distribute this software/file and its
%%   documentation for any purpose without permission by UNIVERSITAET OLDENBURG
%%   is not granted.
%%   
%%   Permission to use this software for academic purposes is generally
%%   granted.
%%
%%   Permission to modify the software is granted, but not the right to
%%   distribute the modified code.
%%
%%   This software is provided "as is" without expressed or implied warranty.
%%
%%   Author:    Michael Kleinschmidt
%%   Co-Author: Bernd Meyer 
%%
%%   Please contact Bernd Meyer (bernd.meyer@uni-oldenburg.de) for 
%%   questions regarding this release.
%%-----------------------------------------------------------------------------
